import platform
import io

from odoo import models, tools, api

from PIL import Image



class OETestTool(models.TransientModel):
    _name = "openerp.enterprise.tool"
    _description = "openerp.enterprise.tool"

    @api.model
    def _set_domain(self, domain=False):
        if not domain:
            generic_domain = {
                "staging10.test.odoo.com": "https://www.test.odoo.com",
            }
            name = platform.node().replace('test-ob', 'staging').replace('next-ob', 'staging')
            domain = generic_domain.get(name, f'https://{name}')

        self.env.ref('website.default_website').domain = domain
        self.env['ir.config_parameter'].set_param('web.base.url', domain)

    @api.model
    def _get_default_favicon(self):
        colors = [
            (136, 176, 75), (247, 202, 201),
            (146, 168, 209), (149, 82, 81),
            (181, 101, 167), (0, 155, 119),
            (221, 65, 36), (68, 184, 172),
            (239, 192, 80), (91, 94, 166),
        ]

        staging = self.env['ir.config_parameter'].sudo().get_param('web.base.url', '')
        staging_num = int("".join([i for i in staging.split('.')[0] if i.isdigit()]) or 0) % 10

        with tools.file_open('web/static/img/favicon.ico', 'rb') as f:
            # Modify the source image to add a colored bar on the bottom
            # This could seem overkill to modify the pixels 1 by 1, but
            # Pillow doesn't provide an easy way to do it, and this
            # is acceptable for a 16x16 image.
            color = colors[staging_num]
            original = Image.open(f)
            new_image = Image.new('RGBA', original.size)
            height = original.size[1]
            width = original.size[0]
            bar_size = 1
            for y in range(height):
                for x in range(width):
                    pixel = original.getpixel((x, y))
                    if height - bar_size <= y + 1 <= height:
                        new_image.putpixel((x, y), (color[0], color[1], color[2], 255))
                    else:
                        new_image.putpixel((x, y), (pixel[0], pixel[1], pixel[2], pixel[3]))
            stream = io.BytesIO()
            new_image.save(stream, format="ICO")
            return stream.getvalue()
